@@ -6,7 +6,7 @@
 import os
 import platform
 import re
-
+import socket
 
 MAC_ADDR_PREFIX = [
     "B8:27:EB",
@@ -18,6 +18,25 @@ MAC_ADDR_PREFIX = [
 ]
 
 
+def get_cur_ip():
+    try:
+        s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+        s.connect(('8.8.8.8', 80))
+        return s.getsockname()[0]
+    finally:
+        s.close()
+
+
+def ping(ip):
+    if not ip:
+        return
+
+    prefix = ip.rsplit(".", maxsplit=1)[0]
+
+    for x in range(0x1, 0xff):
+        os.popen(f"ping {prefix}.{x}")
+
+
 def get_raspberry_pi():
     cur_system = platform.system()
     command = f"""arp -na | grep -i -E '{"|".join(MAC_ADDR_PREFIX)}'"""
@@ -25,6 +44,8 @@ def get_raspberry_pi():
     if "window" in cur_system.lower():
         command = f'''arp -a | findstr -i "{' '.join(MAC_ADDR_PREFIX)}"'''
 
+    ping(get_cur_ip())
+
     res = os.popen(command).read()
     if not res:
         return
@@ -47,3 +68,6 @@ def get_raspberry_pi():
         }
         devices.append(device)
     return devices
+
+
+ping(get_cur_ip())
\ No newline at end of file
